@@ -1,9 +1,9 @@
 import numpy as np
-import pandas as pd
 import numba
 from warnings import warn
 
 try:
+    import pandas as pd
     import datashader as ds
     import datashader.transfer_functions as tf
     import datashader.bundling as bd
@@ -25,11 +25,11 @@ except ImportError:
 
     or via conda using
 
-    conda install datashader bokeh holoviews colorcet
+     conda install pandas matplotlib datashader bokeh holoviews colorcet
     """
     )
     raise ImportError(
-        "umap.plot requires matplotlib, datashader, colorcet and holoviews to be "
+        "umap.plot requires pandas matplotlib datashader bokeh holoviews and colorcet to be "
         "installed"
     ) from None
 
@@ -42,7 +42,6 @@ from matplotlib.patches import Patch
 from umap.nndescent import initialise_search, initialized_nnd_search
 from umap.utils import deheap_sort, submatrix
 
-from bokeh.plotting import output_notebook, output_file
 from bokeh.plotting import show as show_interactive
 from matplotlib.pyplot import show as show_static
 
@@ -166,14 +165,24 @@ def _nhood_search(umap_object, nhood_size):
     else:
         rng_state = np.empty(3, dtype=np.int64)
 
+        if len(umap_object._metric_kwds) >= 1:
+            _dist = umap_object._input_distance_func
+            _args = tuple(umap_object._metric_kwds.values())
+
+            @numba.njit()
+            def _metric(x, y):
+                _dist(x, y, *_args)
+
+        else:
+            _metric = umap_object._input_distance_func
+
         init = initialise_search(
             umap_object._rp_forest,
             umap_object._raw_data,
             umap_object._raw_data,
             int(nhood_size * umap_object.transform_queue_size),
             rng_state,
-            umap_object._distance_func,
-            umap_object._dist_args,
+            _metric,
         )
 
         result = initialized_nnd_search(
@@ -182,8 +191,7 @@ def _nhood_search(umap_object, nhood_size):
             umap_object._search_graph.indices,
             init,
             umap_object._raw_data,
-            umap_object._distance_func,
-            umap_object._dist_args,
+            _metric,
         )
 
         indices, dists = deheap_sort(result)
